@@ -11,7 +11,7 @@
 
 // own
 #include "module.h"
-#include "modulesmodel.h"
+#include "modulesproxymodel.h"
 #include "settingsapp.h"
 #include "version.h"
 
@@ -29,7 +29,6 @@
 #include <KLocalizedContext>
 #include <KLocalizedString>
 #include <KPackage/PackageLoader>
-#include <KPluginLoader>
 #include <KPluginMetaData>
 
 #include <KPackage/Package>
@@ -108,7 +107,8 @@ int main(int argc, char **argv)
             // qDebug() << "Formafactors: " << formFactors;
         }
 
-        const auto kcmPlugin = KPluginLoader::findPlugins("kcms");
+        const auto kcmPlugin = KPluginMetaData::findPlugins("kcms")
+            << KPluginMetaData::findPlugins("plasma/kcms") << KPluginMetaData::findPlugins("plasma/kcms/systemsettings");
         for (const auto &plugin : kcmPlugin) {
             if (seen.contains(plugin.pluginId())) {
                 continue;
@@ -143,7 +143,7 @@ int main(int argc, char **argv)
     settingsApp->setStartModule(module);
     settingsApp->setSingleModule(singleModule);
 
-    qmlRegisterType<ModulesModel>("org.kde.plasma.settings", 0, 1, "ModulesModel");
+    qmlRegisterType<ModulesProxyModel>("org.kde.plasma.settings", 0, 1, "ModulesProxyModel");
     qmlRegisterType<Module>("org.kde.plasma.settings", 0, 1, "Module");
     qmlRegisterSingletonInstance<SettingsApp>("org.kde.plasma.settings", 0, 1, "SettingsApp", settingsApp);
 
